@@ -39,11 +39,11 @@ function cs(bool $dryRun = false): int
 #[AsTask(description: 'install dependencies')]
 function install(): void
 {
-    run(['composer', 'install'], context: context()->withWorkingDirectory(__DIR__));
+    run(['composer', 'install'], context()->withWorkingDirectory(__DIR__));
 }
 
 #[AsTask(description: 'Update dependencies')]
 function update(): void
 {
-    run(['composer', 'update'], context: context()->withWorkingDirectory(__DIR__));
+    run(['composer', 'update'], context()->withWorkingDirectory(__DIR__));
 }
